<?php
/**
 * @package   	      Easy Digital Downloads - Digital Signature Add-on
 * @contributors	  Kevin Michael Gray (Approve Me), Abu Shoaib (Approve Me)
 * @wordpress-plugin
 * Plugin Name:       Easy Digital Downloads - Digital Signature Add-on
 * Plugin URI:        http://aprv.me/2lQS3xk
 * Description:       Digital Signature lets you require customers to sign one (or more) legally binding WP e-Signature contracts before they can complete their Easy Digital Download checkout process. WP E-Signature by ApproveMe business license is required.
 * Version:           1.5.7.1
 * Author:            Approve Me
 * Author URI:        http://aprv.me/2lQS3xk
 * Text Domain:       edd-esig
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

define('ESIGN_EDD_PATH',  dirname(__FILE__));
define('ESIGN_EDD_URL',  plugins_url("",__FILE__));

add_action('plugins_loaded', 'esig_loads_edd_digital_signature');

function esig_loads_edd_digital_signature() {

    if (class_exists('Esig_Edd_Requirement')) {
        return;
    }
    
    require_once 'includes/esig-edd-settings.php';
    require_once 'includes/esig-edd-requirement.php';
    Esig_Edd_Requirement::Init();

    if (Esig_Edd_Requirement::is_required_plugin_install()) {

        require_once 'includes/class-esig-edd-sad.php';
        
        
        if (is_admin()) {
            // admin stuff goes here 
            require_once 'includes/esig-edd-admin.php';
            require_once 'includes/edd-data.php';
            require_once 'includes/esig-edd-admin-options.php';
            // admin init 
            ESIG_EDD_Admin::Init();
            ESIG_EDD_Options::Init();
            esigEddData::instance();  
        } 
            // front end stuff goes here 
             require_once 'includes/esig-edd-frontend.php';
             ESIG_EDD_Frontend::Init();
       
        // loads langauges packages . 
        load_plugin_textdomain('edd-esig', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }
}

/*
 * Register hooks that are fired when the plugin is activated or deactivated.
 * When the plugin is deleted, the uninstall.php file is loaded.
 */
register_activation_hook(__FILE__, 'esig_edd_activate');
register_deactivation_hook(__FILE__, 'esig_edd_deactivate');

require_once( plugin_dir_path( __FILE__ ) . 'about/autoload.php' );

/**
 * Fired when the plugin is activated.
 *
 * @since     0.1
 * @param    boolean    $network_wide    True if WPMU superadmin uses
 *                                       "Network Activate" action, false if
 *                                       WPMU is disabled or plugin is
 *                                       activated on an individual blog.
 */
function esig_edd_activate($network_wide) {

    set_transient('_esign_edd_redirect', true, 30);
}

/**
 * Fired when the plugin is deactivated.
 *
 * @since     0.1
 * @param    boolean    $network_wide    True if WPMU superadmin uses
 *                                       "Network Deactivate" action, false if
 *                                       WPMU is disabled or plugin is
 *                                       deactivated on an individual blog.
 */
function esig_edd_deactivate($network_wide) {
    
}
