<?php

class Esig_Edd_Settings {

    const PRODUCT_AGREEMENT_ID = '_esig_edd_meta_product_agreement';
    const PRODUCT_SAD_PAGE = '_esig_edd_meta_sad_page';
    const PRODUCT_SIGNING_LOGIC = '_esign_edd_sign_logic';
    const ESIG_EDD_SESSION = 'esig-edd-signature';
    const EDD_COOKIE = 'esig-edd-temp-cookie';

    public static $instantAccess;

    //*********** product agreement ************************//

    public static function save_product_agreement($post_id, $value) {
        update_post_meta($post_id, self::PRODUCT_AGREEMENT_ID, $value);
    }

    public static function get_product_agreement($post_id) {
        return get_post_meta($post_id, self::PRODUCT_AGREEMENT_ID, true);
    }

    public static function is_product_agreement_enabled($post_id) {
        if (self::get_product_agreement($post_id)) {
            return true;
        } else {
            return false;
        }
    }

    //******************** product sad page ***************//

    public static function save_product_sad_page($post_id, $value) {
        update_post_meta($post_id, self::PRODUCT_SAD_PAGE, $value);
    }

    public static function get_product_sad_page($post_id) {
        return get_post_meta($post_id, self::PRODUCT_SAD_PAGE, true);
    }

    //****************** product signing logic **************//

    public static function save_product_signing_logic($post_id, $value) {
        update_post_meta($post_id, self::PRODUCT_SIGNING_LOGIC, $value);
    }

    public static function get_product_signing_logic($post_id) {
        return get_post_meta($post_id, self::PRODUCT_SIGNING_LOGIC, true);
    }

    public static function is_product_logic($post_id, $logic) {
        $checkout_logic = self::get_product_signing_logic($post_id);
        if ($checkout_logic === $logic) {
            return true;
        }
        return false;
    }

    //******************* temp cookie settings *****************//
    public static function get_temp_settings() {
        if (!empty(self::$instantAccess)) {
            return self::$instantAccess;
        }
        if (ESIG_COOKIE(self::EDD_COOKIE)) {
            return json_decode(stripslashes(ESIG_COOKIE(self::EDD_COOKIE)), true);
        }
        return false;
    }

    public static function save_temp_settings($value) {
        $json = json_encode($value);
        esig_setcookie(self::EDD_COOKIE, $json, 600);
        // for instant cookie load. 
        $_COOKIE[self::EDD_COOKIE] = $json;
        self::$instantAccess = $value;
    }

    public static function delete_temp_settings() {

        esig_unsetcookie(self::EDD_COOKIE, COOKIEPATH);
    }

    public static function save_esig_edd_meta($meta_key, $meta_value) {

        $temp_settings = self::get_temp_settings();

        if (!$temp_settings) {
            $temp_settings = array();
            $temp_settings[$meta_key] = $meta_value;
            // finally save slv settings . 
            self::save_temp_settings($temp_settings);
        } else {

            if (array_key_exists($meta_key, $temp_settings)) {
                $temp_settings[$meta_key] = $meta_value;
                self::save_temp_settings($temp_settings);
            } else {
                $temp_settings[$meta_key] = $meta_value;
                self::save_temp_settings($temp_settings);
            }
        }
    }

    public static function get_esig_edd_meta($meta_key, $meta_index) {

        $temp_settings = self::get_temp_settings();
        if (is_array($temp_settings)) {
            if (!array_key_exists($meta_key, $temp_settings)) {
                return false;
            }

            return $temp_settings[$meta_key];
        }
        return false;
    }

    //************* Global settings ************************//

    public static function get_global_sad_page() {
        return edd_get_option('esign_edd_sad_page');
    }

    public static function is_global_agreement_enabled() {
        if (edd_get_option('esign_edd_agreement_setting')) {
            return true;
        } else {
            return false;
        }
    }

    public static function get_global_signing_logic() {
        return edd_get_option('esign_edd_signing_logic');
    }

    public static function is_global_logic($logic) {
        $checkout_logic = self::get_global_signing_logic();
        if ($checkout_logic === $logic) {
            return true;
        }
        return false;
    }

    //******************** Hundle session here ****************//

    public static function set_agreement_list($sad_page_id, $signed = false) {

        /* if (EDD()->session->get(self::ESIG_EDD_SESSION)) {
          $wp_esign = EDD()->session->get(self::ESIG_EDD_SESSION);
          $wp_esign[$sad_page_id] = $signed;
          EDD()->session->set(self::ESIG_EDD_SESSION, $wp_esign);
          } else {
          $wp_esign = array();
          $wp_esign[$sad_page_id] = $signed;
          EDD()->session->set(self::ESIG_EDD_SESSION, $wp_esign);
          } */
        self::save_esig_edd_meta($sad_page_id, $signed);
    }

    public static function is_agreement_page_signed($sad_page_id) {
        $wp_esign = self::get_temp_settings();
        if (!$wp_esign) {
            return false;
        }
        if (is_array($wp_esign) && array_key_exists($sad_page_id, $wp_esign)) {
            if ($wp_esign[$sad_page_id]) {
                return true;
            }
        }
        return false;
    }

    public static function get_required_agreement_list() {
        //return EDD()->session->get(self::ESIG_EDD_SESSION);
        return self::get_temp_settings();
    }

    public static function is_signature_required() {
        if (is_array(self::get_required_agreement_list())) {
            return true;
        }

        return false;
    }

    public static function edd_purchase_complete($payment_id) {

        $requiredAgreementList  = self::get_required_agreement_list();
        if(!is_array($requiredAgreementList))
        {
            return false; 
        }

        foreach ($requiredAgreementList as $page_id => $document_id) {
            if ($document_id) {
                WP_E_Sig()->meta->add($document_id, 'esig-edd-payment-id', $payment_id);
                WP_E_Sig()->meta->add($document_id, 'esig-edd-signed', 'signed');
            }
        }
    }

    public static function sad_page_id($sad_doc_id) {
        $edd_sad = new esig_edd_sad();
        return $edd_sad->get_sadpage_id_document_id($sad_doc_id);
    }

    public static function set_temp_payment_id($payment_id) {
        //EDD()->session->set("esig-edd-payment-id", $payment_id);
        esig_setcookie('esig-edd-payment-id', $payment_id, 600);
        $_COOKIE['esig-edd-payment-id'] = $payment_id;
    }

    public static function get_temp_payment_id() {
        //return EDD()->session->get("esig-edd-payment-id");
        if (ESIG_COOKIE('esig-edd-payment-id')) {
            return ESIG_COOKIE('esig-edd-payment-id');
        }
        return false;
    }

    public static function delete_temp_payment_id() {
        esig_unsetcookie('esig-edd-payment-id', COOKIEPATH);
    }

    public static function get_payment_id($document_id, $invitation_id) {

        $payment_id = WP_E_Sig()->setting->get_generic('esig-edd-payment-id' . $invitation_id);

        if (!$payment_id) {

            $payment_id = WP_E_Sig()->meta->get($document_id, 'esig-edd-payment-id');
        }
        if (!$payment_id) {
            $payment_id = self::get_temp_payment_id();
        }
        return $payment_id;
    }

    public static function get_payment_key($payment_id) {
        return edd_get_payment_key($payment_id);
    }

    public static function set_temp_site_transient($payment_key) {
        set_site_transient('esig-edd-shortcode-view', $payment_key, 120);
    }

    public static function remove_temp_site_transient() {
        delete_site_transient('esig-edd-shortcode-view');
    }

    public static function is_edd_shortcode_view() {
        if (get_site_transient('esig-edd-shortcode-view')) {
            return true;
        }
        return false;
    }

    public static function orderDetails($payment_id) {

        $meta = edd_get_payment_meta($payment_id);

        $user = edd_get_payment_meta_user_info($payment_id);
        $payment = new EDD_Payment($payment_id);
        $result = array(
            "payment_key" => $payment->key,
            "payment_currency" => $payment->currency,
            "payment_gateway" => $payment->gateway,
            "payment_date" => date_i18n(get_option('date_format'), strtotime($meta['date'])),
            "wpuser_first_name" => $user['first_name'],
            "wpuser_last_name" => $user['last_name'],
            "wpuser_email" => $user['email'],
            "customer_email" => $payment->email,
            "customer_ip_address" => $payment->ip,
            "customer_first_name" => $payment->first_name,
            "customer_last_name" => $payment->last_name,
            "transaction_id" => $payment->transaction_id,
            "payment_total" => $payment->total,
            "payment_subtotal" => edd_get_payment_subtotal($payment_id),
            "payment_tax" => edd_get_payment_tax($payment_id),
            "payment_discount" => $payment->discounts,
            "payment_status" => $payment->status,
        );

        // order product details . 
        $cart = edd_get_payment_meta_cart_details($payment_id, true);

        if ($cart) {
            foreach ($cart as $itemData) {
                $result['download_' . $itemData['id'] . '_name'] = $itemData['name'];
                $result['download_' . $itemData['id'] . '_quantity'] = $itemData['quantity'];
                $result['download_' . $itemData['id'] . '_price'] = $itemData['item_price'];
            }
        }
        return $result;
    }

    public static function esigget($name, $array = null) {

        if (!isset($array) && function_exists('ESIG_GET')) {
            return ESIG_GET($name);
        }

        if (is_array($array)) {
            if (isset($array[$name])) {
                return wp_unslash($array[$name]);
            }
            return false;
        }

        if (is_object($array)) {
            if (isset($array->$name)) {
                return wp_unslash($array->$name);
            }
            return false;
        }

        return false;
    }

}
